import os
import yaml
from toybag import enumerate

def _addGlobalComments(vil, infoDir):
    "vil is a VorbisInfoList that already has objects in it"
    try:
        comments = list(yaml.loadFile(os.path.join(infoDir,
                                                   'globalcomments.txt')))
        for inComment in comments:
            for vi in vil:
                vi.comments.merge(inComment)
    except IOError:
        pass # guess there weren't any global comments...

def _addComments(vilfoDir):
    try:
        comments = list(yaml.loadFile(join(infoDir, 'comments.txt')))[0]
        for (inComment, vi), i in enumerate(zip(comments, vil), 1):
            vi.comments.merge(inComment)
            vi.comments.insert(('tracknumber', str(i)))

    except IOError:
        raise RuntimeWarning, 'eek, no comments!'

def _addGlobalPragmas(vil, infoDir):
    try:
        pragmas = yaml.loadFile(os.path.join(infoDir,
                                             'globalpragmas.txt'))
        for pragma in pragmas:
            vil.pragmas.update(pragma)
    except IOError:
        pass # guess there were no pragmas there...

def _addPragmas(vil, infoDir):
    try:
        pragmas = yaml.loadFile(os.path.join(infoDir, 'pragmas.txt'))
        list(pragmas) # XXX: I don't know what it does, but it makes
                      # pragmas suitable for the following for-loop.
        for tracknum, pragma in pragmas:
            index = int(tracknum) - 1 # lists are 0-indexed, CDs, 1-
            vil[index].pragmas.update(pragma)
    except IOError:
        pass # guess there were no pragmas...

def add(vil, infoDir):
    if len(vil) == 0: raise ValueError, 'need a populated VorbisInfoList'
    _addGlobalComments(vil, infoDir)
    _addComments(vil, infoDir)
    _addGlobalPragmas(vil, infoDir)
    _addPragmas(vil, infoDir)

if __name__ == '__main__':
    print 'fake test...'
