#!/usr/bin/env python
# Unit test for sonice
# Copyright (c) 2002 Nathan Sharfi
# Copyright terms are included in a file called 'license.txt'.

import sys, os
import unittest

if os.path.abspath(sys.argv[0]).find('sonice') != -1: # if 'sonice' not in path
    sys.path.insert(0, os.path.normpath(os.path.join(
        os.path.abspath(sys.argv[0]), os.pardir, os.pardir)))

# -- begin test code here -- 

from copy import deepcopy
from libsonice.dicts import MultiDict, InsensitiveDict

class MultiDictTester(unittest.TestCase):

    def _getSingle(self):   return deepcopy(MultiDict({'k': ['v']}))
    def _getMultiple(self): return deepcopy(MultiDict({'k': ['v', 'w'],
                                                       'l': ['x', 'y']}))
    def testInitializer(self):
        """Ensure that multidict can take a mapping of keys to lists of keys
        as an initializer."""
        md = MultiDict({
            'k0': ['v00', 'v01'],
            'k1': ['v10', 'v11']})

    ###########################################################################
    def testIteritems(self):
        """Ensures that md.iteritems() returns an iterator over a list of
        (k, v) pairs."""
        
    def testKeys(self):
        """Ensures that md.keys() returns a list of keys."""
        md = self._getMultiple()
        keys = []
        for k in md.keys():
            keys.append(k)
        keys.sort()
        self.assertEqual(keys, ['k', 'l'])
        
    def testValues(self):
        """Ensures that md.values() returns a list of all values."""
        md = self._getMultiple()
        values = []
        for v in md.values():
            values.append(v)
        values.sort()
        self.assertEqual(values, [['v', 'w'], ['x', 'y']])

    def testItems(self):
        """Ensures that md.items() returns a list of (k, v) pairs."""
        md = self._getMultiple()
        items = [] # will have 2-tuples inside
        for item in md.items():
            items.append(item)
        items.sort()
        self.assertEqual(items,
                         [('k', 'v'), ('k', 'w'), ('l', 'x'), ('l', 'y')])

    ###########################################################################
    def testForIn(self):
        """Ensures that 'for k, v in md' iterates over all (k, v) pairs."""
        md = self._getMultiple()
        keys = []
        values = []

        for k, v in md:
            keys.append(k)
            values.append(v)
            
        self.assertEqual(keys,   ['k', 'k', 'l', 'l'])
        self.assertEqual(values, ['v', 'w', 'x', 'y'])

    def testIn(self):
        """Ensures that 'x in md' checks if x is a key in md."""
        md = self._getMultiple()
        self.failUnless('k' in md)
        
        self.failIf('u' in md)
        self.failIf('v' in md)

##     def test__delitem__(self):
##         lhs = self.getMultiple()
##         rhs = MultiDict({'l': ['x', 'y']})
##         self.assertEqual(
       
class InsensitiveDictTester(unittest.TestCase):
    def _getMixed(self): return deepcopy(InsensitiveDict({'Key': 'value'}))
    def _getUpper(self): return deepcopy(InsensitiveDict({'KEY': 'value'}))
    def _getLower(self): return deepcopy(InsensitiveDict({'key': 'value'}))

    def test__setitem__(self):
        lhs = self._getMixed()
        rhs = InsensitiveDict({'Key': 'another value'})
        lhs['Key'] = 'another value'

        self.assertEqual(lhs, rhs)

    def test__getitem__(self):
        id = self._getMixed()
        self.assertEqual(id['Key'], 'value')

    def testEquality(self):
        mixed = self._getMixed()
        upper = self._getUpper()
        lower = self._getLower()

        self.assertEqual(mixed, upper)
        self.assertEqual(mixed, lower)
        self.assertEqual(upper, lower)

class InsensitiveMultiDictTester(MultiDictTester):
    pass

if __name__ == '__main__':
    unittest.main()
