#!/usr/bin/env python
# Unit test for sonice
# Copyright (c) 2002 Nathan Sharfi
# Copyright terms are included in a file called 'license.txt'.

import sys, os
import unittest

if os.path.abspath(sys.argv[0]).find('sonice') != -1: # if 'sonice' not in path
    sys.path.insert(0, os.path.normpath(os.path.join(
        os.path.abspath(sys.argv[0]), os.pardir, os.pardir)))

# -- begin test code here -- 

import os, sys, unittest, copy

from libsonice.metadata import Comments

class CommentsTester(unittest.TestCase):
    sampleComments = Comments({'artist':      ['Weezer'],
                               'performer':   ['Brian Bell', 'Rivers Cuomo']})
    commentsToInsert = Comments({'title':     ['Pinkerton'],
                                 'performer': ['Matt Sharp']})
    def _dupa(self): return copy.deepcopy(self.sampleComments)
    def _dupb(self): return copy.deepcopy(self.commentsToInsert)
    def testMerge(self):
        """Tests whether I can merge two Comments instances together
        correctly."""

        lhs = self._dupa()
        rhs = self._dupb()

        lhs.merge(rhs)
    
        self.assertEqual(lhs,
                         Comments({'artist': ['Weezer'],
                                   'performer': ['Brian Bell', 'Rivers Cuomo',
                                                 'Matt Sharp'],
                                   'title': ['Pinkerton']}))

    def testMergeBidirectional(self): # transitive? reflexive?
        "Tests if a.merge(b) == b.merge(a)"
        self.assertEqual(self._dupa().merge(self._dupb()),
                         self._dupb().merge(self._dupa()))
        
    def testInsertTuple(self):
        lhs = self._dupa()
        lhs.insert(('producer', 'Ric Ocasek'))
        self.assertEqual(lhs,
                         Comments({'artist': ['Weezer'],
                                   'producer': ['Ric Ocasek'],
                                   'performer':
                                   ['Brian Bell', 'Rivers Cuomo']}))

if __name__ == '__main__':
    unittest.main()
